@@ -3,32 +3,19 @@
 // SPDX-License-Identifier:    MIT
 
 #include "cell.h"
-#include <map>
-#include <xtensor-blas/xlinalg.hpp>
+#include "math.h"
 #include <xtensor/xbuilder.hpp>
-#include <xtensor/xfixed.hpp>
 #include <xtensor/xview.hpp>
 
 using namespace basix;
 
-namespace
-{
-template <typename U, typename V>
-xt::xtensor<double, 1> cross3(const U& u, const V& v)
-{
-  xt::xtensor<double, 1> c = xt::zeros<double>({3});
-  c[0] = u[1] * v[2] - u[2] * v[1];
-  c[1] = u[2] * v[0] - u[0] * v[2];
-  c[2] = u[0] * v[1] - u[1] * v[0];
-  return c;
-}
-} // namespace
-
 //-----------------------------------------------------------------------------
 xt::xtensor<double, 2> cell::geometry(cell::type celltype)
 {
   switch (celltype)
   {
+  case cell::type::point:
+    return xt::xtensor<double, 2>({{}});
   case cell::type::interval:
     return xt::xtensor<double, 2>({{0.0}, {1.0}});
   case cell::type::triangle:
@@ -68,37 +55,37 @@ xt::xtensor<double, 2> cell::geometry(cell::type celltype)
 //-----------------------------------------------------------------------------
 std::vector<std::vector<std::vector<int>>> cell::topology(cell::type celltype)
 {
-  std::vector<std::vector<std::vector<int>>> t;
-
   switch (celltype)
   {
+  case cell::type::point:
+    return {{{0}}};
   case cell::type::interval:
-    t.resize(2);
-    // Vertices
-    t[0] = {{0}, {1}};
-    // Cell
-    t[1] = {{0, 1}};
-    break;
+    return {{{0}, {1}}, {{0, 1}}};
   case cell::type::triangle:
-    t.resize(3);
+  {
+    std::vector<std::vector<std::vector<int>>> t(3);
     // Vertices
     t[0] = {{0}, {1}, {2}};
     // Edges
     t[1] = {{1, 2}, {0, 2}, {0, 1}};
     // Cell
     t[2] = {{0, 1, 2}};
-    break;
+    return t;
+  }
   case cell::type::quadrilateral:
-    t.resize(3);
+  {
+    std::vector<std::vector<std::vector<int>>> t(3);
     // Vertices
     t[0] = {{0}, {1}, {2}, {3}};
     // Edges
     t[1] = {{0, 1}, {0, 2}, {1, 3}, {2, 3}};
     // Cell
     t[2] = {{0, 1, 2, 3}};
-    break;
+    return t;
+  }
   case cell::type::tetrahedron:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<int>>> t(4);
     // Vertices
     t[0] = {{0}, {1}, {2}, {3}};
     // Edges
@@ -107,9 +94,11 @@ std::vector<std::vector<std::vector<int>>> cell::topology(cell::type celltype)
     t[2] = {{1, 2, 3}, {0, 2, 3}, {0, 1, 3}, {0, 1, 2}};
     // Cell
     t[3] = {{0, 1, 2, 3}};
-    break;
+    return t;
+  }
   case cell::type::prism:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<int>>> t(4);
     // Vertices
     t[0] = {{0}, {1}, {2}, {3}, {4}, {5}};
     // Edges
@@ -119,9 +108,11 @@ std::vector<std::vector<std::vector<int>>> cell::topology(cell::type celltype)
     t[2] = {{0, 1, 2}, {0, 1, 3, 4}, {0, 2, 3, 5}, {1, 2, 4, 5}, {3, 4, 5}};
     // Cell
     t[3] = {{0, 1, 2, 3, 4, 5}};
-    break;
+    return t;
+  }
   case cell::type::pyramid:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<int>>> t(4);
     // Vertices
     t[0] = {{0}, {1}, {2}, {3}, {4}};
     // Edges
@@ -130,9 +121,11 @@ std::vector<std::vector<std::vector<int>>> cell::topology(cell::type celltype)
     t[2] = {{0, 1, 2, 3}, {0, 1, 4}, {0, 2, 4}, {1, 3, 4}, {2, 3, 4}};
     // Cell
     t[3] = {{0, 1, 2, 3, 4}};
-    break;
+    return t;
+  }
   case cell::type::hexahedron:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<int>>> t(4);
     // Vertices
     t[0] = {{0}, {1}, {2}, {3}, {4}, {5}, {6}, {7}};
     // Edges
@@ -143,39 +136,43 @@ std::vector<std::vector<std::vector<int>>> cell::topology(cell::type celltype)
             {1, 3, 5, 7}, {2, 3, 6, 7}, {4, 5, 6, 7}};
     // Cell
     t[3] = {{0, 1, 2, 3, 4, 5, 6, 7}};
-    break;
+    return t;
+  }
   default:
     throw std::runtime_error("Unsupported cell type");
   }
-
-  return t;
 }
 //-----------------------------------------------------------------------------
 std::vector<std::vector<std::vector<std::vector<int>>>>
 cell::sub_entity_connectivity(cell::type celltype)
 {
-  std::vector<std::vector<std::vector<std::vector<int>>>> t;
-
   switch (celltype)
   {
+  case cell::type::point:
+    return {{{{0}}}};
   case cell::type::interval:
-    t.resize(2);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(2);
     // Vertices
     t[0] = {{{0}, {0}}, {{1}, {0}}};
     // Edge
     t[1] = {{{0, 1}, {0}}};
-    break;
+    return t;
+  }
   case cell::type::triangle:
-    t.resize(3);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(3);
     // Vertices
     t[0] = {{{0}, {1, 2}, {0}}, {{1}, {0, 2}, {0}}, {{2}, {0, 1}, {0}}};
     // Edges
     t[1] = {{{1, 2}, {0}, {0}}, {{0, 2}, {1}, {0}}, {{0, 1}, {2}, {0}}};
     // Face
     t[2] = {{{0, 1, 2}, {0, 1, 2}, {0}}};
-    break;
+    return t;
+  }
   case cell::type::quadrilateral:
-    t.resize(3);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(3);
     // Vertices
     t[0] = {{{0}, {0, 1}, {0}},
             {{1}, {0, 2}, {0}},
@@ -188,9 +185,11 @@ cell::sub_entity_connectivity(cell::type celltype)
             {{2, 3}, {3}, {0}}};
     // Face
     t[2] = {{{0, 1, 2, 3}, {0, 1, 2, 3}, {0}}};
-    break;
+    return t;
+  }
   case cell::type::tetrahedron:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(4);
     // Vertices
     t[0] = {{{0}, {3, 4, 5}, {1, 2, 3}, {0}},
             {{1}, {1, 2, 5}, {0, 2, 3}, {0}},
@@ -209,9 +208,11 @@ cell::sub_entity_connectivity(cell::type celltype)
             {{0, 1, 2}, {2, 4, 5}, {3}, {0}}};
     // Volume
     t[3] = {{{0, 1, 2, 3}, {0, 1, 2, 3, 4, 5}, {0, 1, 2, 3}, {0}}};
-    break;
+    return t;
+  }
   case cell::type::hexahedron:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(4);
     // Vertices
     t[0] = {
         {{0}, {0, 1, 2}, {0, 1, 2}, {0}},  {{1}, {0, 3, 4}, {0, 1, 3}, {0}},
@@ -237,9 +238,11 @@ cell::sub_entity_connectivity(cell::type celltype)
              {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11},
              {0, 1, 2, 3, 4, 5},
              {0}}};
-    break;
+    return t;
+  }
   case cell::type::prism:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(4);
     // Vertices
     t[0] = {{{0}, {0, 1, 2}, {0, 1, 2}, {0}}, {{1}, {0, 3, 4}, {0, 1, 3}, {0}},
             {{2}, {1, 3, 5}, {0, 2, 3}, {0}}, {{3}, {2, 6, 7}, {1, 2, 4}, {0}},
@@ -261,9 +264,11 @@ cell::sub_entity_connectivity(cell::type celltype)
              {0, 1, 2, 3, 4, 5, 6, 7, 8},
              {0, 1, 2, 3, 4},
              {0}}};
-    break;
+    return t;
+  }
   case cell::type::pyramid:
-    t.resize(4);
+  {
+    std::vector<std::vector<std::vector<std::vector<int>>>> t(4);
     // Vertices
     t[0] = {{{0}, {0, 1, 2}, {0, 1, 2}, {0}},
             {{1}, {0, 3, 4}, {0, 1, 3}, {0}},
@@ -283,17 +288,19 @@ cell::sub_entity_connectivity(cell::type celltype)
             {{2, 3, 4}, {5, 6, 7}, {4}, {0}}};
     // Volume
     t[3] = {{{0, 1, 2, 3, 4}, {0, 1, 2, 3, 4, 5, 6, 7}, {0, 1, 2, 3, 4}, {0}}};
-    break;
+    return t;
+  }
   default:
     throw std::runtime_error("Unsupported cell type");
   }
-  return t;
 }
 //-----------------------------------------------------------------------------
 int cell::topological_dimension(cell::type cell_type)
 {
   switch (cell_type)
   {
+  case cell::type::point:
+    return 0;
   case cell::type::interval:
     return 1;
   case cell::type::triangle:
@@ -311,7 +318,6 @@ int cell::topological_dimension(cell::type cell_type)
   default:
     throw std::runtime_error("Unsupported cell type");
   }
-  return 0;
 }
 //-----------------------------------------------------------------------------
 xt::xtensor<double, 2> cell::sub_entity_geometry(cell::type celltype, int dim,
@@ -363,48 +369,12 @@ cell::type cell::sub_entity_type(cell::type celltype, int dim, int index)
   }
 }
 //-----------------------------------------------------------------------------
-cell::type cell::str_to_type(std::string name)
-{
-  static const std::map<std::string, cell::type> name_to_type
-      = {{"point", cell::type::point},
-         {"interval", cell::type::interval},
-         {"triangle", cell::type::triangle},
-         {"tetrahedron", cell::type::tetrahedron},
-         {"quadrilateral", cell::type::quadrilateral},
-         {"pyramid", cell::type::pyramid},
-         {"prism", cell::type::prism},
-         {"hexahedron", cell::type::hexahedron}};
-
-  auto it = name_to_type.find(name);
-  if (it == name_to_type.end())
-    throw std::runtime_error("Can't find name " + name);
-
-  return it->second;
-}
-//-----------------------------------------------------------------------------
-const std::string& cell::type_to_str(cell::type type)
-{
-  static const std::map<cell::type, std::string> type_to_name
-      = {{cell::type::point, "point"},
-         {cell::type::interval, "interval"},
-         {cell::type::triangle, "triangle"},
-         {cell::type::tetrahedron, "tetrahedron"},
-         {cell::type::quadrilateral, "quadrilateral"},
-         {cell::type::pyramid, "pyramid"},
-         {cell::type::prism, "prism"},
-         {cell::type::hexahedron, "hexahedron"}};
-
-  auto it = type_to_name.find(type);
-  if (it == type_to_name.end())
-    throw std::runtime_error("Can't find type");
-
-  return it->second;
-}
-//-----------------------------------------------------------------------------
 double cell::volume(cell::type cell_type)
 {
   switch (cell_type)
   {
+  case cell::type::point:
+    return 0;
   case cell::type::interval:
     return 1;
   case cell::type::triangle:
@@ -470,11 +440,10 @@ xt::xtensor<double, 2> cell::facet_normals(cell::type cell_type)
     {
       const std::vector<int>& facet = facets[f];
       auto normal = xt::row(normals, f);
-
       assert(facets[f].size() == 3 or facets[f].size() == 4);
       auto e0 = xt::row(x, facet[1]) - xt::row(x, facet[0]);
       auto e1 = xt::row(x, facet[2]) - xt::row(x, facet[0]);
-      normal = cross3(e0, e1);
+      normal = basix::math::cross(e0, e1);
       normal /= xt::sqrt(xt::sum(normal * normal));
     }
     return normals;
@@ -522,6 +491,8 @@ std::vector<std::vector<cell::type>> cell::subentity_types(cell::type cell_type)
 {
   switch (cell_type)
   {
+  case cell::type::point:
+    return {{cell::type::point}};
   case cell::type::interval:
     return {{cell::type::point, cell::type::point}, {cell::type::interval}};
   case cell::type::triangle:
