@@ -64,15 +64,15 @@ def test_apply_to_transpose(cell_type, element_type, degree, element_args):
         assert np.allclose(data1.transpose(), data2)
 
 
-@parametrize_over_elements(5, "interval")
+@parametrize_over_elements(5, basix.CellType.interval)
 def test_interval_transformation_size(element_type, degree, element_args):
-    e = basix.create_element(element_type, "interval", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.interval, degree, *element_args)
     assert len(e.base_transformations()) == 0
 
 
-@parametrize_over_elements(5, "triangle")
+@parametrize_over_elements(5, basix.CellType.triangle)
 def test_triangle_transformation_degrees(element_type, degree, element_args):
-    e = basix.create_element(element_type, "triangle", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.triangle, degree, *element_args)
     bt = e.base_transformations()
     assert len(bt) == 3
     identity = np.identity(e.dim)
@@ -82,9 +82,9 @@ def test_triangle_transformation_degrees(element_type, degree, element_args):
             identity)
 
 
-@parametrize_over_elements(5, "tetrahedron")
+@parametrize_over_elements(5, basix.CellType.tetrahedron)
 def test_tetrahedron_transformation_degrees(element_type, degree, element_args):
-    e = basix.create_element(element_type, "tetrahedron", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.tetrahedron, degree, *element_args)
     bt = e.base_transformations()
     assert len(bt) == 14
     identity = np.identity(e.dim)
@@ -94,9 +94,9 @@ def test_tetrahedron_transformation_degrees(element_type, degree, element_args):
             identity)
 
 
-@parametrize_over_elements(5, "quadrilateral")
+@parametrize_over_elements(5, basix.CellType.quadrilateral)
 def test_quadrilateral_transformation_degrees(element_type, degree, element_args):
-    e = basix.create_element(element_type, "quadrilateral", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.quadrilateral, degree, *element_args)
     bt = e.base_transformations()
     assert len(bt) == 4
     identity = np.identity(e.dim)
@@ -106,22 +106,23 @@ def test_quadrilateral_transformation_degrees(element_type, degree, element_args
             identity)
 
 
-@parametrize_over_elements(5, "hexahedron")
+@parametrize_over_elements(5, basix.CellType.hexahedron)
 def test_hexahedron_transformation_degrees(element_type, degree, element_args):
-    e = basix.create_element(element_type, "hexahedron", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.hexahedron, degree, *element_args)
     bt = e.base_transformations()
     assert len(bt) == 24
     identity = np.identity(e.dim)
     for i, degree in enumerate([2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
                                4, 2, 4, 2, 4, 2, 4, 2, 4, 2, 4, 2]):
+        # TODO: remove the atol here once non-equispaced variants are implemented
         assert np.allclose(
             np.linalg.matrix_power(bt[i], degree),
-            identity)
+            identity, atol=1e-6)
 
 
-@parametrize_over_elements(5, "prism")
+@parametrize_over_elements(5, basix.CellType.prism)
 def test_prism_transformation_degrees(element_type, degree, element_args):
-    e = basix.create_element(element_type, "prism", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.prism, degree, *element_args)
     bt = e.base_transformations()
     assert len(bt) == 19
     identity = np.identity(e.dim)
@@ -132,9 +133,9 @@ def test_prism_transformation_degrees(element_type, degree, element_args):
             identity)
 
 
-@parametrize_over_elements(5, "pyramid")
+@parametrize_over_elements(5, basix.CellType.pyramid)
 def test_pyramid_transformation_degrees(element_type, degree, element_args):
-    e = basix.create_element(element_type, "pyramid", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.pyramid, degree, *element_args)
     bt = e.base_transformations()
     assert len(bt) == 18
     identity = np.identity(e.dim)
@@ -145,27 +146,27 @@ def test_pyramid_transformation_degrees(element_type, degree, element_args):
             identity)
 
 
-@parametrize_over_elements(5, "triangle")
+@parametrize_over_elements(5, basix.CellType.triangle)
 def test_transformation_of_tabulated_data_triangle(element_type, degree, element_args):
-    e = basix.create_element(element_type, "triangle", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.triangle, degree, *element_args)
     bt = e.base_transformations()
 
     N = 4
     points = np.array([[i / N, j / N] for i in range(N + 1) for j in range(N + 1 - i)])
-    values = e.tabulate_x(0, points)[0]
+    values = e.tabulate(0, points)[0]
 
     start = sum(e.num_entity_dofs[0])
     ndofs = e.num_entity_dofs[1][0]
     if ndofs != 0:
         # Check that the 0th transformation undoes the effect of reflecting edge 0
         reflected_points = np.array([[p[1], p[0]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[0, 1], [1, 0]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
 
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
@@ -175,27 +176,27 @@ def test_transformation_of_tabulated_data_triangle(element_type, degree, element
                                    j_slice[start: start + ndofs])
 
 
-@parametrize_over_elements(5, "quadrilateral")
+@parametrize_over_elements(5, basix.CellType.quadrilateral)
 def test_transformation_of_tabulated_data_quadrilateral(element_type, degree, element_args):
-    e = basix.create_element(element_type, "quadrilateral", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.quadrilateral, degree, *element_args)
     bt = e.base_transformations()
 
     N = 4
     points = np.array([[i / N, j / N] for i in range(N + 1) for j in range(N + 1)])
-    values = e.tabulate_x(0, points)[0]
+    values = e.tabulate(0, points)[0]
 
     start = sum(e.num_entity_dofs[0])
     ndofs = e.num_entity_dofs[1][0]
     if ndofs != 0:
         # Check that the 0th transformation undoes the effect of reflecting edge 0
         reflected_points = np.array([[1 - p[0], p[1]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[-1, 0], [0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -204,28 +205,28 @@ def test_transformation_of_tabulated_data_quadrilateral(element_type, degree, el
                                    j_slice[start: start + ndofs])
 
 
-@parametrize_over_elements(5, "tetrahedron")
+@parametrize_over_elements(5, basix.CellType.tetrahedron)
 def test_transformation_of_tabulated_data_tetrahedron(element_type, degree, element_args):
-    e = basix.create_element(element_type, "tetrahedron", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.tetrahedron, degree, *element_args)
     bt = e.base_transformations()
 
     N = 4
     points = np.array([[i / N, j / N, k / N]
                        for i in range(N + 1) for j in range(N + 1 - i) for k in range(N + 1 - i - j)])
-    values = e.tabulate_x(0, points)[0]
+    values = e.tabulate(0, points)[0]
 
     start = sum(e.num_entity_dofs[0])
     ndofs = e.num_entity_dofs[1][0]
     if ndofs != 0:
         # Check that the 0th transformation undoes the effect of reflecting edge 0
         reflected_points = np.array([[p[0], p[2], p[1]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[1, 0, 0], [0, 0, 1], [0, 1, 0]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -238,13 +239,13 @@ def test_transformation_of_tabulated_data_tetrahedron(element_type, degree, elem
     if ndofs != 0:
         # Check that the 6th transformation undoes the effect of rotating face 0
         rotated_points = np.array([[p[2], p[0], p[1]] for p in points])
-        rotated_values = e.tabulate_x(0, rotated_points)[0]
+        rotated_values = e.tabulate(0, rotated_points)[0]
 
         _J = np.array([[0, 1, 0], [0, 0, 1], [1, 0, 0]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(rotated_values, J, detJ, K)
+        mapped_values = e.push_forward(rotated_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -255,13 +256,13 @@ def test_transformation_of_tabulated_data_tetrahedron(element_type, degree, elem
     if ndofs != 0:
         # Check that the 7th transformation undoes the effect of reflecting face 0
         reflected_points = np.array([[p[0], p[2], p[1]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[1, 0, 0], [0, 0, 1], [0, 1, 0]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -270,32 +271,32 @@ def test_transformation_of_tabulated_data_tetrahedron(element_type, degree, elem
                                    j_slice[start: start + ndofs])
 
 
-@parametrize_over_elements(3, "hexahedron")
+@parametrize_over_elements(3, basix.CellType.hexahedron)
 def test_transformation_of_tabulated_data_hexahedron(element_type, degree, element_args):
-    if degree > 4 and element_type in ["Raviart-Thomas", "Nedelec 1st kind H(curl)"]:
+    if degree > 4 and element_type in [basix.ElementFamily.RT, basix.ElementFamily.N1E]:
         pytest.xfail("High degree Hdiv and Hcurl spaces on hexes based on "
                      "Lagrange spaces equally spaced points are unstable.")
 
-    e = basix.create_element(element_type, "hexahedron", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.hexahedron, degree, *element_args)
     bt = e.base_transformations()
 
     N = 4
     points = np.array([[i / N, j / N, k / N]
                        for i in range(N + 1) for j in range(N + 1) for k in range(N + 1)])
-    values = e.tabulate_x(0, points)[0]
+    values = e.tabulate(0, points)[0]
 
     start = sum(e.num_entity_dofs[0])
     ndofs = e.num_entity_dofs[1][0]
     if ndofs != 0:
         # Check that the 0th transformation undoes the effect of reflecting edge 0
         reflected_points = np.array([[1 - p[0], p[1], p[2]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[-1, 0, 0], [0, 1, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -308,13 +309,13 @@ def test_transformation_of_tabulated_data_hexahedron(element_type, degree, eleme
     if ndofs != 0:
         # Check that the 12th transformation undoes the effect of rotating face 0
         rotated_points = np.array([[1 - p[1], p[0], p[2]] for p in points])
-        rotated_values = e.tabulate_x(0, rotated_points)[0]
+        rotated_values = e.tabulate(0, rotated_points)[0]
 
         _J = np.array([[0, 1, 0], [-1, 0, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(rotated_values, J, detJ, K)
+        mapped_values = e.push_forward(rotated_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -325,13 +326,13 @@ def test_transformation_of_tabulated_data_hexahedron(element_type, degree, eleme
     if ndofs != 0:
         # Check that the 13th transformation undoes the effect of reflecting face 0
         reflected_points = np.array([[p[1], p[0], p[2]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -340,28 +341,28 @@ def test_transformation_of_tabulated_data_hexahedron(element_type, degree, eleme
                                    j_slice[start: start + ndofs])
 
 
-@parametrize_over_elements(3, "prism")
+@parametrize_over_elements(3, basix.CellType.prism)
 def test_transformation_of_tabulated_data_prism(element_type, degree, element_args):
-    e = basix.create_element(element_type, "prism", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.prism, degree, *element_args)
     bt = e.base_transformations()
 
     N = 4
     points = np.array([[i / N, j / N, k / N]
                        for i in range(N + 1) for j in range(N + 1 - i) for k in range(N + 1)])
-    values = e.tabulate_x(0, points)[0]
+    values = e.tabulate(0, points)[0]
 
     start = sum(e.num_entity_dofs[0])
     ndofs = e.num_entity_dofs[1][0]
     if ndofs != 0:
         # Check that the 0th transformation undoes the effect of reflecting edge 0
         reflected_points = np.array([[1 - p[1] - p[0], p[1], p[2]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[-1, 0, 0], [-1, 1, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -374,13 +375,13 @@ def test_transformation_of_tabulated_data_prism(element_type, degree, element_ar
     if ndofs != 0:
         # Check that the 10th transformation undoes the effect of rotating face 0
         rotated_points = np.array([[1 - p[0] - p[1], p[0], p[2]] for p in points])
-        rotated_values = e.tabulate_x(0, rotated_points)[0]
+        rotated_values = e.tabulate(0, rotated_points)[0]
 
         _J = np.array([[-1, 1, 0], [-1, 0, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(rotated_values, J, detJ, K)
+        mapped_values = e.push_forward(rotated_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -391,13 +392,13 @@ def test_transformation_of_tabulated_data_prism(element_type, degree, element_ar
     if ndofs != 0:
         # Check that the 11th transformation undoes the effect of reflecting face 0
         reflected_points = np.array([[p[1], p[0], p[2]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -406,28 +407,28 @@ def test_transformation_of_tabulated_data_prism(element_type, degree, element_ar
                                    j_slice[start: start + ndofs])
 
 
-@parametrize_over_elements(3, "pyramid")
+@parametrize_over_elements(3, basix.CellType.pyramid)
 def test_transformation_of_tabulated_data_pyramid(element_type, degree, element_args):
-    e = basix.create_element(element_type, "pyramid", degree, *element_args)
+    e = basix.create_element(element_type, basix.CellType.pyramid, degree, *element_args)
     bt = e.base_transformations()
 
     N = 4
     points = np.array([[i / N, j / N, k / N]
                        for i in range(N + 1) for j in range(N + 1 - i) for k in range(N + 1)])
-    values = e.tabulate_x(0, points)[0]
+    values = e.tabulate(0, points)[0]
 
     start = sum(e.num_entity_dofs[0])
     ndofs = e.num_entity_dofs[1][0]
     if ndofs != 0:
         # Check that the 0th transformation undoes the effect of reflecting edge 0
         reflected_points = np.array([[1 - p[2] - p[0], p[1], p[2]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[-1, 0, 0], [0, 1, 0], [-1, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -440,13 +441,13 @@ def test_transformation_of_tabulated_data_pyramid(element_type, degree, element_
     if ndofs != 0:
         # Check that the 8th transformation undoes the effect of rotating face 0
         rotated_points = np.array([[1 - p[1] - p[2], p[0], p[2]] for p in points])
-        rotated_values = e.tabulate_x(0, rotated_points)[0]
+        rotated_values = e.tabulate(0, rotated_points)[0]
 
         _J = np.array([[0, 1, 0], [-1, 0, 0], [-1, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(rotated_values, J, detJ, K)
+        mapped_values = e.push_forward(rotated_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
@@ -457,13 +458,13 @@ def test_transformation_of_tabulated_data_pyramid(element_type, degree, element_
     if ndofs != 0:
         # Check that the 9th transformation undoes the effect of reflecting face 0
         reflected_points = np.array([[p[1], p[0], p[2]] for p in points])
-        reflected_values = e.tabulate_x(0, reflected_points)[0]
+        reflected_values = e.tabulate(0, reflected_points)[0]
 
         _J = np.array([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
         J = np.array([_J for p in points])
         detJ = np.array([np.linalg.det(_J) for p in points])
         K = np.array([np.linalg.inv(_J) for p in points])
-        mapped_values = e.map_push_forward(reflected_values, J, detJ, K)
+        mapped_values = e.push_forward(reflected_values, J, detJ, K)
         for i, j in zip(values, mapped_values):
             for d in range(e.value_size):
                 i_slice = i[:, d]
